
class Page:
    def init(self, screen):
        pass
    def activate(self, screen):
        pass
    def handleEvent(self, event):
        return event
    def render(self, screen, deltat):
        pass

